.. _bluegraph_backends_neo4j_ref:

`neo4j` package
--------------------

Reference page for the `bluegraph.backends.neo4j` package. All the interfaces below are also available as `bluegraph.backends.neo4j.<interface>` (for example, :code:`from bluegraph.backends.neo4j import Neo4jPathFinder`).


Graph metrics
^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.neo4j.analyse.metrics
	:members:


Path search
^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.neo4j.analyse.paths
	:members:


Community Detection
^^^^^^^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.neo4j.analyse.communities
	:members:


Node embedding
^^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.neo4j.embed.embedders
	:members:
